==> qt-creator-1.2.1-src.zip: qt-creator-1.2.1-src/src/plugins/designer/settingspage.cpp <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://www.qtsoftware.com/contact.
**
**************************************************************************/

#include "settingspage.h"

#include <extensionsystem/pluginmanager.h>
#include <qt_private/abstractoptionspage_p.h>

using namespace Designer::Internal;

SettingsPage::SettingsPage(QDesignerOptionsPageInterface *designerPage) :
    m_designerPage(designerPage)
{
}

SettingsPage::~SettingsPage()
{
}

QString SettingsPage::id() const
{
    return m_designerPage->name();
}

QString SettingsPage::trName() const
{
    return m_designerPage->name();
}

QString SettingsPage::category() const
{
    return QLatin1String("Designer");
}

QString SettingsPage::trCategory() const
{
    return tr("Designer");
}

QWidget *SettingsPage::createPage(QWidget *parent)
{
    return m_designerPage->createPage(parent);
}

void SettingsPage::apply()
{
    m_designerPage->apply();
}

void SettingsPage::finish()
{
    m_designerPage->finish();
}

==> qt-creator-1.2.90-src.zip: qt-creator-1.2.90-src/src/plugins/designer/settingspage.cpp <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#include "settingspage.h"
#include "designerconstants.h"

#include <extensionsystem/pluginmanager.h>
#include <qt_private/abstractoptionspage_p.h>
#include <QtCore/QCoreApplication>

using namespace Designer::Internal;

SettingsPage::SettingsPage(QDesignerOptionsPageInterface *designerPage) :
    m_designerPage(designerPage)
{
}

SettingsPage::~SettingsPage()
{
}

QString SettingsPage::id() const
{
    return m_designerPage->name();
}

QString SettingsPage::trName() const
{
    return m_designerPage->name();
}

QString SettingsPage::category() const
{
    return QLatin1String(Designer::Constants::SETTINGS_CATEGORY);
}

QString SettingsPage::trCategory() const
{
    return QCoreApplication::translate("Designer", Designer::Constants::SETTINGS_CATEGORY);
}

QWidget *SettingsPage::createPage(QWidget *parent)
{
    return m_designerPage->createPage(parent);
}

void SettingsPage::apply()
{
    m_designerPage->apply();
}

void SettingsPage::finish()
{
    m_designerPage->finish();
}
